=== modified file 'NEWS'
--- NEWS	2022-08-08 16:33:50 +0000
+++ NEWS	2022-08-08 17:26:06 +0000
@@ -18,6 +18,13 @@
 
     - Port from SimpleTAL to Chameleon. (Colin Watson)
 
+    - Modernize packaging.  There are new dependencies on
+      ``importlib_metadata`` (for Python < 3.8) and ``packaging``, in order
+      to avoid a self-import in ``setup.py``.  People proxying Loggerhead
+      through Apache should install the ``loggerhead[proxied]`` extra;
+      people running it via FastCGI, SCGI, or AJP should install the
+      ``loggerhead[flup]`` extra. (Colin Watson, #1831661)
+
 1.20.0 [18Jul2021]
 ------------------
 

=== modified file '__init__.py'
--- __init__.py	2018-11-03 18:15:51 +0000
+++ __init__.py	2022-08-08 17:26:06 +0000
@@ -30,9 +30,19 @@
 starts a web server to browse the contents of a branch.
 """
 
+try:
+    import importlib.metadata as importlib_metadata
+except ImportError:
+    import importlib_metadata
 import sys
 
-version_info = (1, 20, 0) # Keep in sync with loggerhead/__init__.py
+from packaging.version import Version
+
+try:
+    version_info = Version(importlib_metadata.version("loggerhead")).release
+except importlib_metadata.PackageNotFoundError:
+    # Support running tests from the build tree without installation.
+    version_info = None
 
 import breezy
 from breezy import commands

=== modified file 'docs/conf.py'
--- docs/conf.py	2010-03-25 10:25:13 +0000
+++ docs/conf.py	2022-08-08 17:26:06 +0000
@@ -11,7 +11,7 @@
 # All configuration values have a default; values that are commented out
 # serve to show the default.
 
-import sys, os
+from loggerhead import __version__
 
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
@@ -45,9 +45,9 @@
 # built documents.
 #
 # The short X.Y version.
-version = '1.17'
+version = __version__
 # The full version, including alpha/beta/rc tags.
-release = '1.17'
+release = __version__
 
 # The language for content autogenerated by Sphinx. Refer to documentation
 # for a list of supported languages.

=== modified file 'docs/index.rst'
--- docs/index.rst	2022-08-08 16:33:50 +0000
+++ docs/index.rst	2022-08-08 17:26:06 +0000
@@ -17,7 +17,7 @@
 
 - Paste for the server. (You need version 1.2 or newer of Paste).
 
-- Paste Deploy  (optional, needed when proxying through Apache).
+- PasteDeploy (optional, needed when proxying through Apache).
 
 - flup (optional, needed to use FastCGI, SCGI or AJP).
 
@@ -32,15 +32,19 @@
    $ sudo apt-get install python-pastedeploy
    $ sudo apt-get install python-flup
 
-Installing Dependencies Using :command:`easy_install`
-#####################################################
+Installing Dependencies Using :command:`pip`
+############################################
+
+You should normally create and activate a virtual environment first.
 
 .. code-block:: sh
 
-   $ easy_install Chameleon
-   $ easy_install Paste
-   $ easy_install PasteDeploy
-   $ easy_install flup
+   # Basic installation only
+   $ pip install loggerhead
+   # Installation for proxying through Apache
+   $ pip install 'loggerhead[proxied]'
+   # Installation for FastCGI, SCGI or AJP
+   $ pip install 'loggerhead[flup]'
 
 
 Running the Standalone Loggerhead Server

=== modified file 'loggerhead/__init__.py'
--- loggerhead/__init__.py	2021-11-15 14:40:11 +0000
+++ loggerhead/__init__.py	2022-08-08 17:26:06 +0000
@@ -15,20 +15,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1335  USA
 
-"""A simple container to turn this into a python package.
-
-We also check the versions of some dependencies.
-"""
-
-import pkg_resources
-
-__version__ = '1.20.0'  # Keep in sync with ../__init__.py.
+"""A simple container to turn this into a python package."""
+
+try:
+    import importlib.metadata as importlib_metadata
+except ImportError:
+    import importlib_metadata
+
+try:
+    __version__ = importlib_metadata.version("loggerhead")
+except importlib_metadata.PackageNotFoundError:
+    # Support running tests from the build tree without installation.
+    __version__ = None
 __revision__ = None
 required_breezy = (3, 1)
-
-pkg_resources.get_distribution('Paste>=1.6')
-try:
-    pkg_resources.get_distribution('PasteDeploy>=1.3')
-except pkg_resources.DistributionNotFound:
-    # No paste.deploy is OK, but an old paste.deploy is bad.
-    pass

=== added file 'setup.cfg'
--- setup.cfg	1970-01-01 00:00:00 +0000
+++ setup.cfg	2022-08-08 17:26:06 +0000
@@ -0,0 +1,66 @@
+# Copyright (C) 2008-2022 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+[metadata]
+name = loggerhead
+version = 2.0.0.dev0
+description = Loggerhead is a web viewer for projects in bazaar
+long_description = file: README.rst
+long_description_content_type = text/x-rst
+license = GNU GPL v2 or later
+maintainer = Michael Hudson
+maintainer_email = michael.hudson@canonical.com
+
+[options]
+scripts =
+    loggerhead-serve
+packages =
+    breezy.plugins.loggerhead
+    loggerhead
+    loggerhead.apps
+    loggerhead.controllers
+    loggerhead.middleware
+    loggerhead.templates
+package_dir =
+    breezy.plugins.loggerhead=.
+install_requires =
+    Chameleon
+    Paste>=1.6
+    bleach
+    breezy>=3.1
+    importlib-metadata; python_version < "3.8"
+    packaging
+
+[options.data_files]
+share/man/man1 =
+    loggerhead-serve.1
+share/doc/loggerhead =
+    apache-loggerhead.conf
+    breezy.conf
+    loggerheadd
+
+[options.extras_require]
+proxied =
+    PasteDeploy>=1.3
+flup =
+    flup
+
+[options.package_data]
+loggerhead =
+    static/css/*.css
+    static/images/*
+    static/javascript/*.js
+    templates/*.pt

=== modified file 'setup.py'
--- setup.py	2022-02-23 19:28:51 +0000
+++ setup.py	2022-08-08 17:26:06 +0000
@@ -20,46 +20,4 @@
 
 from setuptools import setup
 
-import loggerhead
-
-
-with open("README.rst") as readme:
-    long_description = readme.read()
-
-
-setup(
-    name="loggerhead",
-    version=loggerhead.__version__,
-    description="Loggerhead is a web viewer for projects in bazaar",
-    long_description=long_description,
-    long_description_content_type="text/x-rst",
-    license="GNU GPL v2 or later",
-    maintainer="Michael Hudson",
-    maintainer_email="michael.hudson@canonical.com",
-    scripts=[
-        "loggerhead-serve",
-        ],
-    packages=["loggerhead",
-              "loggerhead/apps",
-              "loggerhead/controllers",
-              "loggerhead/middleware",
-              "loggerhead/templates",
-              "breezy.plugins.loggerhead"],
-    package_dir={'breezy.plugins.loggerhead': '.'},
-    package_data={"loggerhead": ["templates/*.pt",
-                                 "static/css/*.css",
-                                 "static/javascript/*.js",
-                                 "static/images/*"]},
-    data_files=[
-        ('share/man/man1', ['loggerhead-serve.1']),
-        ('share/doc/loggerhead', ['apache-loggerhead.conf',
-                                  'loggerheadd',
-                                  'breezy.conf']),
-        ],
-    install_requires=[
-        'paste',
-        'bleach',
-        'breezy>=3.1',
-    ],
-    testsuite='loggerhead.tests.test_suite',
-    )
+setup()

